@@ -1,5 +1,5 @@
 package Test::PDL;
-$Test::PDL::VERSION = '0.18';
+$Test::PDL::VERSION = '0.19';
 # ABSTRACT: Test Perl Data Language arrays (a.k.a. ndarrays) for equality
 
 
@@ -66,9 +66,9 @@ sub _comparison_fails
 		return 'bad value patterns do not match';
 	}
 	return 'values do not match'
-		if ( $got->isnull and !$expected->isnull)
-		or (!$got->isnull and  $expected->isnull);
-	return 0 if $got->isnull and $expected->isnull;
+		if ( $got->isempty and !$expected->isempty)
+		or (!$got->isempty and  $expected->isempty);
+	return 0 if $got->isempty and $expected->isempty;
 	# if we get here, bad value patterns are sure to match
 	if( $got->type < PDL::float && $expected->type < PDL::float ) {
 		if( not eval { PDL::all( $got == $expected ) } ) {
@@ -187,7 +187,7 @@ Test::PDL - Test Perl Data Language arrays (a.k.a. ndarrays) for equality
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
